@@ -73,7 +73,7 @@ def _get_system_lshw_dict():
 
     :return: A python dict from the lshw json output
     """
-    out, _e = utils.execute('lshw', '-quiet', '-json')
+    out, _e = utils.execute('lshw', '-quiet', '-json', log_stdout=False)
     return json.loads(out)
 
 
@@ -822,7 +822,7 @@ class GenericHardwareManager(HardwareManager):
         try:
             sys_dict = _get_system_lshw_dict()
         except (processutils.ProcessExecutionError, OSError, ValueError) as e:
-            LOG.warning('Could not retrieve vendor info from lshw: %e', e)
+            LOG.warning('Could not retrieve vendor info from lshw: %s', e)
             sys_dict = {}
         return SystemVendorInfo(product_name=sys_dict.get('product', ''),
                                 serial_number=sys_dict.get('serial', ''),
